From 84ede803777ff10b5cbe93b1ec0168af08f55d5e Mon Sep 17 00:00:00 2001
From: hxp <ale99527@vip.qq.com>
Date: 星期三, 13 一月 2021 18:11:26 +0800
Subject: [PATCH] 8677 【BT】【后端】跨服冲榜活动; 新增跨服活动时间管理模块、跨服榜单;跨服邮件;跨服广播优化;相关GM命令、后台工具;

---
 ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py |   10 +++++++---
 1 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
index f187085..d683796 100644
--- a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
+++ b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GM/Commands/Success.py
@@ -72,6 +72,7 @@
             if succType not in resetTypeList:
                 resetTypeList.append(succType)
             PlayerSuccess.SetSuccHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccPassportAwardHasGot(curPlayer, succID, False)
             PlayerSuccess.SetSuccFinish(curPlayer, succID, False)
             PlayerSuccess.SetPDictValue(curPlayer, ChConfig.Def_PDict_Success_LastDay % (succID), 0)
             PlayerSuccess.SetSuccFinishValue(curPlayer, succType, succDataObj.condition, 0)
@@ -100,9 +101,11 @@
         
         for succDataObj in succDataList:
             succID = succDataObj.succID
-            if not PlayerSuccess.GetSuccHasGot(curPlayer, succID):
+            if not PlayerSuccess.GetSuccHasGot(curPlayer, succID) and not PlayerSuccess.GetSuccPassportAwardHasGot(curPlayer, succID):
                 continue
             PlayerSuccess.SetSuccHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccPassportAwardHasGot(curPlayer, succID, False)
+            PlayerSuccess.SetSuccFinish(curPlayer, succID) # 有重置领奖的ID需要重新设置为已完成
             resetIDList.append(succID)
             
     # 同步成就领奖记录
@@ -132,8 +135,9 @@
                 GameWorld.DebugAnswer(curPlayer, "成就类型: %s" % succType)
             isFinish = PlayerSuccess.GetSuccIsFinish(curPlayer, succID)
             hasGot = PlayerSuccess.GetSuccHasGot(curPlayer, succID)
-            GameWorld.DebugAnswer(curPlayer, "    id=%s 条件:%s 进度:%s/%s 完成:%s 领奖:%s" 
-                                  % (succID, succDataObj.condition, value, succDataObj.needCnt, isFinish, hasGot))
+            passportHasGot = PlayerSuccess.GetSuccPassportAwardHasGot(curPlayer, succID)
+            GameWorld.DebugAnswer(curPlayer, "    id=%s 条件:%s 进度:%s/%s 完成:%s 领奖:%s %s" 
+                                  % (succID, succDataObj.condition, value, succDataObj.needCnt, isFinish, hasGot, passportHasGot))
             
     return
 

--
Gitblit v1.8.0